﻿/// <reference path="/@JSense.js" />
Sw.Controllers.Compareable("Sw.Controllers.TrafficSources", {},
{

    init: function (el, options) {
        this._super(el, options);
        this.chart = el.find(".chart");
        this.legend = this.chart.parent("article").find(".traffic-sources-legend");
        this.onWindowResize();
    },

    /* These methods are called from the base controller after formating the data needed for the site */
    onSiteCompareAdded: function (site, data) {

        var that = this;
        that.addLegendItem(site.name, site.slot);

        $.each(data, function (key, item) {

            switch (key) {
                case "Search": that.addColumn(site.name, site.slot, item, "traffic-search"); break;
                case "Social": that.addColumn(site.name, site.slot, item, "social"); break;
                case "Mail": that.addColumn(site.name, site.slot, item, "mail"); break;
                case "Paid Referrals": that.addColumn(site.name, site.slot, item, "display-ads"); break;
                case "Direct": that.addColumn(site.name, site.slot, item, "direct"); break;
                case "Referrals": that.addColumn(site.name, site.slot, item, "referrals"); break;
            }



        });

        $(window).trigger("resize");

    },

    addLegendItem: function (site, slot) {

        var _legendItem = "";

        _legendItem = "<div class='legend-item legend-item-id-" + slot + "'>";
        _legendItem += "<span class='legend-color-item legend-color" + slot + "'></span>";
        _legendItem += "<span class='legend-key'>" + site + "</span>";
        _legendItem += "</div>";

        this.legend.append(_legendItem);

        if ($(".legend-item").length > 1) {
            $(".legend-item-id-0").show();
        }

    },

    onSiteCompareRemoved: function (site) {

        $(".legend-item-id-" + site.slot).remove();

        if ($(".legend-item").length == 1) {
            $(".legend-item-id-0").hide();
        }

        this.removeColumn(site.slot);
    },

    onSiteCompareFailed: function (site, reason) {

    },

    onWindowResize: function () {
        var that = this;
        $(window).resize(function () {

            that.reCalculateColumns(that);
            that.reCalculateLabels();

        });
    },

    reCalculateColumns: function (control) {

        var parent = control.chart.parents("article.trafficsources.component"),
            parent_width = parent.width(),
            chart_size = Math.floor((parent_width - 20) / 6);

        parent.find(".column .graph").width(chart_size + "px");


    },

    reCalculateLabels: function () {
        var _labels = $(".column .graph").find(".label");

        $.each(_labels, function (key, item) {

            try {

                var _label = $(item);
                var _graph = _label.parents(".graph");
                var _slot = _label.data("slot");

                _label.css("left", _graph.find(".slot" + _slot).position().left);
                _label.css("bottom", _where.find(".slot" + _slot).height() + 4 + "px");
            }
            catch (ex) {
            }

        });
    },

    addColumn: function (site, slot, data, where) {

        var _where = this.chart.find(".column." + where).find(".graph");
        var _series = $("<div class='series'></div>");
        var _label = $("<span class='label slot'></span>");
        var _percentage = this.formattedPercentage(data);
        var _seriesCount;

        _series.css("height", (parseFloat(_percentage) <= 1.0) ? 1.0 : _percentage + "%");
        _series.css("margin-top", 100 - _series.height());
        _series.addClass("slot" + slot);


        _series.data("slot", slot);

        _label.html(_percentage + "%");
        _label.addClass("slot" + slot);

        if (parseFloat(_percentage) >= 65) {
            _label.addClass("high");
            _label.css("margin-bottom", "0");
        }

        _where.append(_series);
        _where.append(_label);
        _seriesCount = this.getSeriesCount(_where)


        this.updateSeriesSize(_where);

        if (_seriesCount == 1) {
            _where.addClass("size1Of" + _seriesCount);
        }
        else {
            _where.removeClass("size1Of" + (_seriesCount - 1));
            _where.addClass("size1Of" + _seriesCount);
        }

        //this.rearrengeSeries(_where);

        try {
            _label.css("left", _where.find(".slot" + slot).position().left);
            _label.data("slot", slot);
            _label.css("bottom", _where.find(".slot" + slot).height() + 4 + "px");

            if (_label.hasClass("high")) {
                _label.css("bottom", "5px");
            }

            $(window).trigger("resize");
        }
        catch (ex) {
        }

        //$(window).trigger("resize");

    },

    rearrengeSeries: function (where) {

        var secondlabel = where.find(".label:nth-child(4)");
        secondlabel.addClass("position-2").removeClass("position-3");

        where.find(".label").not(".slot0, .position-2").addClass("position-3");
    },

    getSeriesCount: function (where) {
        return where.find(".series").length;
    },

    updateSeriesSize: function (where) {
        var size = this.getSeriesCount(where);
        size = 100 / size;
        where.find(".series").css("width", size + "%");
    },

    removeColumn: function (slot) {

        var that = this;
        var _chart = that.chart;
        var _series = _chart.find(".graph").find(".series");

        _chart.find(".graph").find(".slot" + slot).remove();

        $.each(_series, function (key, value) {

            var _column = $(this).parents(".column");
            var _slot = $(this).data("slot");

            _column.find(".label").filter(".slot" + _slot).css("left", $(this).position().left);
            that.updateSeriesSize(_column);

            _column.find(".graph").removeClass("size1Of" + (that.getSeriesCount(_column) + 1)).addClass("size1Of" + that.getSeriesCount(_column));
            //that.rearrengeSeries(_column);
        });

    },

    formattedPercentage: function (value) {
        return (value * 100).toFixed(2);
    }
});